<template>
  <div>
    <el-dialog
        v-model="dialogVisible"
        :title="title"
        width="600"
        :close-on-click-modal="false"
        :before-close="handleClose"
    >
      <el-form
          ref="formRef"
          style="max-width: 400px; margin: 0 auto"
          :model="formData"
          :rules="rules"
          label-width="auto"
      >
        <el-form-item label="字段名称" prop="fieldName">
          <el-input
              v-model="formData.fieldName"
              placeholder="请输入字段名称"
              :disabled="isViewMode"
              @blur="checkFieldNameExists"
          />
        </el-form-item>
        <el-form-item label="字段描述" prop="fieldDescription">
          <el-input v-model="formData.fieldDescription" type="textarea" placeholder="请输入字段描述" :disabled="isViewMode"/>
        </el-form-item>
        <el-form-item class="dialog-footer">
          <el-button v-if="addOrEdit === 'edit'" @click="resetForm"
          >重置
          </el-button
          >
          <el-button v-if="addOrEdit === 'add' || addOrEdit.includes('viewRow')" @click="cancelForm"
          >取消
          </el-button
          >
          <el-button type="primary" v-if="!isViewMode" @click="submitForm" > 确定</el-button>
        </el-form-item>
      </el-form>
    </el-dialog>
  </div>
</template>

<script setup>
import {ref, reactive, watch, defineProps, computed, onMounted} from "vue";
import {ElMessage} from "element-plus";
import {addOrEditCoalField} from "@/api/basicInformation/coalFieldMaintenance.js";
import {getCoalFieldList} from "@/api/publicApi/index.js";

const props = defineProps({
  form: {
    type: Object,
    default: () => ({}),
  },
  addOrEdit: {
    type: String,
    default: "add",
  },
  title: {
    type: String,
    default: "",
  },
});
const isViewMode = computed(() => {
  return props.addOrEdit.includes("view");
});
const copyForm = defineModel("copyForm", {
  required: true,
  type: Object,
});

// 存储已有的字段列表
const existingFields = ref([]);

// 组件挂载时获取已有字段列表
onMounted(async () => {
  try {
    const {data, code} = await getCoalFieldList();
    if (code === 200) {
      existingFields.value = data || [];
    }
  } catch (error) {
    console.error("获取字段列表失败", error);
  }
});
// 表单引用
const formRef = ref();
const emit = defineEmits(["submit", "handleBeforeClose"]);
// 表单数据
const formData = ref({...props.form});

// 监听props.form的变化，更新formData
watch(() => props.form, (newForm) => {
  formData.value = {...newForm};
}, {deep: true, immediate: true});
// 弹窗可见性
const dialogVisible = defineModel("coalMaintenanceFieldDialogVisible", {
  required: true,
  type: Boolean,
});
// 提交表单
const submitForm = async () => {
  if (!formRef.value) return;
  await formRef.value.validate(async (valid, fields) => {
    if (valid) {
      const obj = ref({});

      console.log("提交表单", formData.value);
      if (props.title.includes('新增')) {
        let result = await addOrEditCoalField(
            {...formData.value}
            ,)
        console.log(result);
        obj.value = {
          title: "新增",
          ...formData.value,
          result
        };
      } else {
        let result = await addOrEditCoalField({
          ...formData.value,
        })
        obj.value = {
          title: "编辑",
          ...formData.value,
          result
        };
      }
      emit("submit", obj.value);
    }
  });
};
// 取消表单
const cancelForm = () => {
  emit("update:coalMaintenanceFieldDialogVisible", false);
  formData.value = {};
};
// 重置表单
const resetForm = () => {
  if (!formRef.value) return
  formData.value = JSON.parse(JSON.stringify(copyForm.value));
}
// 关闭弹窗
const handleClose = () => {
  // 触发父组件的关闭函数
  emit("handleBeforeClose");
  emit("update:coalMaintenanceFieldDialogVisible", false);
};

// 检查字段名称是否已存在
const checkFieldNameExists = () => {
  if (!formData.value.fieldName) return;
  
  const isNameExists = existingFields.value.some(field => 
    field.fieldName === formData.value.fieldName
  );
  
  // 编辑模式下，如果是当前字段的原名称则不提示
  if (isNameExists && !(props.addOrEdit === 'edit' && props.form.fieldName === formData.value.fieldName)) {
    ElMessage.warning("该字段名称已存在，请换其他名字");
    // 可选：自动清空输入框
    // formData.value.fieldName = '';
  }
};
const rules = reactive({
  fieldName: [
    {required: true, message: "请输入字段名称", trigger: "blur"},
    {
      validator: (rule, value, callback) => {
        if (!value) {
          callback();
          return;
        }
        // 检查字段名称是否已存在
        const isNameExists = existingFields.value.some(field => 
          field.fieldName === value
        );
        
        // 编辑模式下，如果是当前字段的原名称则允许
        if (isNameExists) {
          if (props.addOrEdit === 'edit' && props.form.fieldName === value) {
            callback();
          } else {
            callback(new Error("该字段名称已存在，请换其他名字"));
          }
        } else {
          callback();
        }
      },
      trigger: "blur"
    }
  ],
});
</script>
<style lang="scss" scoped>
.dialog-footer {
  display: flex;
  justify-content: flex-end;
  margin-top: 20px;
  flex-direction: column;
}
</style>